@@ -358,11 +358,11 @@ class Sequential():
                             axs1[1].set_xlabel("Epoch")
                             axs1[1].set_ylabel("Accuracy")
                             
-                            axs1[0].plot(self.train_loss_records, color="#1f77b4", label="training dataset")
-                            axs1[1].plot(self.train_accuracy_records, color="#1f77b4", label="training dataset")
+                            axs1[0].plot(self.train_loss_records, color="#1f77b4", label=f"training dataset: {np.around(self.train_cost_fn.loss(self.train_targets, self.train_outputs),5)}")
+                            axs1[1].plot(self.train_accuracy_records, color="#1f77b4", label=f"training dataset: {np.around(self.accuracy(self.train_targets,self.train_outputs),5)}")
                             if self.val_inputs is not None and self.val_targets is not None:
-                                axs1[0].plot(self.val_loss_records, color="orange", label="validation dataset")
-                                axs1[1].plot(self.val_accuracy_records, color="orange", label="validation dataset")
+                                axs1[0].plot(self.val_loss_records, color="orange", label=f"validation dataset: {np.around(self.val_cost_fn.loss(self.val_targets, self.val_outputs),5)}")
+                                axs1[1].plot(self.val_accuracy_records, color="orange", label=f"validation dataset: {np.around(self.accuracy(self.val_targets,self.val_outputs),5)}")
                                 
                             axs1[0].legend()
                             axs1[1].legend()
@@ -373,7 +373,7 @@ class Sequential():
                         if live_stats == 2 or live_stats == -1:
                             axs2.cla()
                             
-                            if len(self.train_inputs[0,:]) <= 2:
+                            if len(self.train_inputs[0,:]) <= 2 and len(self.train_targets[0,:]) == 1:
                                 X_set, y_set = self.train_inputs, self.train_targets
                                 X1, X2 = np.meshgrid(np.arange(start = X_set[:, 0].min() - 1, stop = X_set[:, 0].max() + 1, step = 0.01),
                                                      np.arange(start = X_set[:, 1].min() - 1, stop = X_set[:, 1].max() + 1, step = 0.01))
@@ -411,11 +411,11 @@ class Sequential():
                             axs1[1].set_xlabel("Epoch")
                             axs1[1].set_ylabel("Accuracy")
                             
-                            axs1[0].plot(self.train_loss_records, color="#1f77b4", label="training dataset")
-                            axs1[1].plot(self.train_accuracy_records, color="#1f77b4", label="training dataset")
+                            axs1[0].plot(self.train_loss_records, color="#1f77b4", label=f"training dataset: {np.around(self.train_cost_fn.loss(self.train_targets, self.train_outputs),5)}")
+                            axs1[1].plot(self.train_accuracy_records, color="#1f77b4", label=f"training dataset: {np.around(self.accuracy(self.train_targets,self.train_outputs),5)}")
                             if self.val_inputs is not None and self.val_targets is not None:
-                                axs1[0].plot(self.val_loss_records, color="orange", label="validation dataset")
-                                axs1[1].plot(self.val_accuracy_records, color="orange", label="validation dataset")
+                                axs1[0].plot(self.val_loss_records, color="orange", label=f"validation dataset: {np.around(self.val_cost_fn.loss(self.val_targets, self.val_outputs),5)}")
+                                axs1[1].plot(self.val_accuracy_records, color="orange", label=f"validation dataset: {np.around(self.accuracy(self.val_targets,self.val_outputs),5)}")
                             
                             axs1[0].legend()
                             axs1[1].legend()
@@ -426,7 +426,7 @@ class Sequential():
                         if live_stats == 2 or live_stats == -1:
                             axs2.cla()
                             
-                            if len(self.train_inputs[0,:]) <= 2:
+                            if len(self.train_inputs[0,:]) <= 2 and len(self.train_targets[0,:]) == 1:
                                 X_set, y_set = self.train_inputs, self.train_targets
                                 X1, X2 = np.meshgrid(np.arange(start = X_set[:, 0].min() - 1, stop = X_set[:, 0].max() + 1, step = 0.01),
                                                      np.arange(start = X_set[:, 1].min() - 1, stop = X_set[:, 1].max() + 1, step = 0.01))
